@@ -540,7 +540,7 @@ string Configuration::FindAny(const char *Name,const char *Default) const
 // Configuration::CndSet - Conditional Set a value			/*{{{*/
 // ---------------------------------------------------------------------
 /* This will not overwrite */
-void Configuration::CndSet(const char *Name,const string &Value)
+void Configuration::CndSet(const char *Name,const string_view &Value)
 {
    Item *Itm = Lookup(Name,true);
    if (Itm == 0)
@@ -565,7 +565,7 @@ void Configuration::CndSet(const char *Name,int const Value)
 // Configuration::Set - Set a value					/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-void Configuration::Set(const char *Name,const string &Value)
+void Configuration::Set(const char *Name,const string_view &Value)
 {
    Item *Itm = Lookup(Name,true);
    if (Itm == 0)
@@ -678,6 +678,10 @@ void Configuration::Clear(string const &Name)
 }
 									/*}}}*/
 void Configuration::MoveSubTree(char const * const OldRootName, char const * const NewRootName)/*{{{*/
+{
+   return MoveSubTree(OldRootName, NewRootName, true);
+}
+void Configuration::MoveSubTree(char const *const OldRootName, char const *const NewRootName, bool Overwrite)
 {
    // prevent NewRoot being a subtree of OldRoot
    if (OldRootName == nullptr)
@@ -713,7 +717,10 @@ void Configuration::MoveSubTree(char const * const OldRootName, char const * con
 
       while (Top != 0 && Top->Next == 0)
       {
-	 Set(NewRoot + Top->FullTag(OldRoot), Top->Value);
+	 if (Overwrite)
+	    Set(NewRoot + Top->FullTag(OldRoot), Top->Value);
+	 else
+	    CndSet((NewRoot + Top->FullTag(OldRoot)).c_str(), Top->Value);
 	 Item const * const Tmp = Top;
 	 Top = Top->Parent;
 	 delete Tmp;
@@ -721,8 +728,10 @@ void Configuration::MoveSubTree(char const * const OldRootName, char const * con
 	 if (Top == Stop)
 	    return;
       }
-
-      Set(NewRoot + Top->FullTag(OldRoot), Top->Value);
+      if (Overwrite)
+	 Set(NewRoot + Top->FullTag(OldRoot), Top->Value);
+      else
+	 CndSet((NewRoot + Top->FullTag(OldRoot)).c_str(), Top->Value);
       Item const * const Tmp = Top;
       if (Top != 0)
 	 Top = Top->Next;
@@ -1226,3 +1235,36 @@ bool Configuration::MatchAgainstConfig::Match(char const * str) const
    return false;
 }
 									/*}}}*/
+// helper for Install-Recommends-Sections and Never-MarkAuto-Sections	/*{{{*/
+static bool ConfigValueInSubTree(Configuration *config, const char *SubTree, std::string_view const needle)
+{
+   if (needle.empty())
+      return false;
+   Configuration::Item const *Opts = config->Tree(SubTree);
+   if (Opts != nullptr && Opts->Child != nullptr)
+   {
+      Opts = Opts->Child;
+      for (; Opts != nullptr; Opts = Opts->Next)
+      {
+	 if (Opts->Value.empty())
+	    continue;
+	 if (needle == Opts->Value)
+	    return true;
+      }
+   }
+   return false;
+}
+bool Configuration::SectionInSubTree(char const *const SubTree, std::string_view Needle)
+{
+   if (ConfigValueInSubTree(this, SubTree, Needle))
+      return true;
+   auto const sub = Needle.rfind('/');
+   if (sub == std::string_view::npos)
+   {
+      std::string special{"/"};
+      special.append(Needle);
+      return ConfigValueInSubTree(this, SubTree, special);
+   }
+   return ConfigValueInSubTree(this, SubTree, Needle.substr(sub + 1));
+}
+									/*}}}*/
