@@ -38,19 +38,6 @@ namespace APT {
    APT_HIDDEN extern std::unordered_map<std::string, std::vector<std::string>> ArchToTupleMap;
 }
 
-// Splits by whitespace. There may be continuous spans of whitespace - they
-// will be considered as one.
-static std::vector<std::string> split(std::string const & s)
-{
-   std::vector<std::string> vec;
-   std::istringstream iss(s);
-   iss.imbue(std::locale::classic());
-   for(std::string current_s; iss >> current_s; )
-      vec.push_back(current_s);
-   return vec;
-}
-
-
 // pkgInitArchTupleMap - Initialize the architecture tuple map				/*{{{*/
 // ---------------------------------------------------------------------
 /* This initializes */
@@ -67,10 +54,10 @@ static bool pkgInitArchTupleMap()
    {
       if (cpuline[0] == '#' || cpuline[0] == '\0')
          continue;
-      auto cpurow = split(cpuline);
+      auto cpurow = APT::String::Split(cpuline);
       auto cpu = APT::String::Strip(cpurow.at(0));
 
-      cpus.push_back(cpu);
+      cpus.emplace_back(cpu);
    }
    if (!cputable.eof())
       return _error->Error("Error reading the CPU table");
@@ -90,21 +77,21 @@ static bool pkgInitArchTupleMap()
       if (tupleline[0] == '#' || tupleline[0] == '\0')
          continue;
 
-      std::vector<std::string> tuplerow = split(tupleline);
+      std::vector<std::string> tuplerow = APT::String::Split(tupleline);
 
       auto tuple = APT::String::Strip(tuplerow.at(0));
       auto arch = APT::String::Strip(tuplerow.at(1));
 
       if (tuple.find("<cpu>") == tuple.npos && arch.find("<cpu>") == arch.npos)
       {
-         APT::ArchToTupleMap.insert({arch, VectorizeString(tuple, '-')});
+         APT::ArchToTupleMap.insert({std::string{arch}, VectorizeString(tuple, '-')});
       }
       else
       {
          for (auto && cpu : cpus)
          {
-            auto mytuple = SubstVar(tuple, std::string("<cpu>"), cpu);
-            auto myarch = SubstVar(arch, std::string("<cpu>"), cpu);
+            auto mytuple = SubstVar(tuple, "<cpu>", cpu);
+            auto myarch = SubstVar(arch, "<cpu>", cpu);
 
             APT::ArchToTupleMap.insert({myarch, VectorizeString(mytuple, '-')});
          }
@@ -159,7 +146,6 @@ bool pkgInitConfig(Configuration &Cnf)
    Cnf.CndSet("Dir::Etc::parts","apt.conf.d");
    Cnf.CndSet("Dir::Etc::preferences","preferences");
    Cnf.CndSet("Dir::Etc::preferencesparts","preferences.d");
-   Cnf.CndSet("Dir::Etc::trusted", "trusted.gpg");
    Cnf.CndSet("Dir::Etc::trustedparts","trusted.gpg.d");
    Cnf.CndSet("Dir::Bin::methods", LIBEXEC_DIR "/methods");
    Cnf.CndSet("Dir::Bin::solvers::",LIBEXEC_DIR  "/solvers");
