@@ -67,14 +67,14 @@
 #include <apt-private/private-upgrade.h>
 #include <apt-private/private-utils.h>
 
-#include <errno.h>
+#include <cerrno>
+#include <csignal>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <grp.h>
 #include <pwd.h>
-#include <signal.h>
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -263,6 +263,8 @@ static bool DoIndexTargets(CommandLine &CmdL)
       if (ReleaseInfo)
       {
 	 AddOptions.insert(std::make_pair("TRUSTED", ((*S)->IsTrusted() ? "yes" : "no")));
+	 if (not (*S)->GetSignedBy().empty())
+	    AddOptions.insert(std::make_pair("SIGNED_BY", SubstVar(SubstVar(APT::String::Strip((*S)->GetSignedBy()), "\n\n", "\n.\n"), "\n", "\n ")));
 	 pkgCache::RlsFileIterator const RlsFile = (*S)->FindInCache(*Cache, false);
 	 if (RlsFile.end())
 	    continue;
@@ -424,6 +426,8 @@ static std::vector<aptDispatchWithHelp> GetCommands()			/*{{{*/
       {"clean", &DoClean, _("Erase downloaded archive files")},
       {"autoclean", &DoAutoClean, _("Erase old downloaded archive files")},
       {"auto-clean", &DoAutoClean, nullptr},
+      {"distclean", &DoDistClean, nullptr},
+      {"dist-clean", &DoDistClean, nullptr},
       {"check", &DoCheck, _("Verify that there are no broken dependencies")},
       {"source", &DoSource, _("Download source archives")},
       {"download", &DoDownload, _("Download the binary package into the current directory")},
